==> sls-dev-tools-1.1.8.tgz: package/lib/services/lambdaLayers.js <==
"use strict";

const fs = require("fs");

function addLayerToLambda(lambdaApi, functionName, layerArn, resolve, reject) {
  const params = {
    FunctionName: functionName,
    Layers: [layerArn],
    Runtime: "provided"
  };
  lambdaApi.updateFunctionConfiguration(params, err => {
    if (err) {
      console.error(err);
      reject();
    }

    console.log("Relay layer added");
    resolve();
  });
}

function createAndAddLambdaLayer(lambdaApi, functionConfig, resolve, reject) {
  console.log("Uploading Lamba Layer...");
  let data;

  try {
    data = fs.readFileSync("resources/layer.zip");
  } catch (err) {
    console.error(err);
    reject();
  }

  const params = {
    Content: {
      ZipFile: data
    },
    CompatibleRuntimes: [functionConfig.Runtime],
    LayerName: "test-node10-layer"
  };
  lambdaApi.publishLayerVersion(params, (err, layer) => {
    if (err) {
      console.error(err);
      reject();
    } else {
      console.log("Layer uploaded. Adding to function...");
      const arn = layer.LayerVersionArn;
      addLayerToLambda(lambdaApi, functionConfig.FunctionName, arn, resolve, reject);
    }
  });
}

function setupLambdaLayer(lambdaApi, functionConfig) {
  // TODO: Determine required layer name using function runtime
  const requiredLayerName = "test-node10-layer";
  console.log("Searching for existing layer");
  const params = {
    CompatibleRuntime: functionConfig.Runtime
  };
  return new Promise((resolve, reject) => {
    lambdaApi.listLayers(params, (err, data) => {
      if (err) {
        console.error(err);
        reject();
      } else {
        const layerFound = data.Layers.some(layer => {
          if (layer.LayerName === requiredLayerName) {
            console.log("Existing layer found. Adding to function...");
            addLayerToLambda(lambdaApi, functionConfig.FunctionName, layer.LatestMatchingVersion.LayerVersionArn, resolve, reject);
            return true;
          }

          return false;
        });

        if (!layerFound) {
          console.log("No existing layer found");
          createAndAddLambdaLayer(lambdaApi, functionConfig, resolve, reject);
        }
      }
    });
  });
}

function removeLambdaLayer(lambdaApi, lambdaName) {
  const params = {
    FunctionName: lambdaName,
    Runtime: "nodejs10.x"
  };
  lambdaApi.updateFunctionConfiguration(params, (err, data) => {
    if (err) {
      console.error(err);
    }

    console.log(data);
  });
}

module.exports = {
  removeLambdaLayer,
  setupLambdaLayer
};

==> sls-dev-tools-1.1.12.tgz: package/lib/services/lambdaLayers.js <==
"use strict";

var _constants = require("../constants");

const fs = require("fs");

function addLayerToLambda(lambdaApi, functionConfig, layerArn, resolve, reject) {
  const layers = functionConfig.Layers;
  let layerArns;

  if (layers) {
    layerArns = layers.map(layer => layer.Arn);
  } else {
    layerArns = [];
  }

  layerArns.push(layerArn);
  const params = {
    FunctionName: functionConfig.FunctionName,
    Layers: layerArns,
    Runtime: "provided"
  };
  lambdaApi.updateFunctionConfiguration(params, err => {
    if (err) {
      console.error(err);
      reject();
    }

    console.log("Relay Layer Added");
    resolve();
  });
}

function createAndAddLambdaLayer(lambdaApi, functionConfig, resolve, reject) {
  console.log("Uploading Lamba Layer...");
  let data;

  try {
    data = fs.readFileSync("resources/layer.zip");
  } catch (err) {
    console.error(err);
    reject();
  }

  const params = {
    Content: {
      ZipFile: data
    },
    CompatibleRuntimes: [functionConfig.Runtime],
    LayerName: _constants.RELAY_LAYER_ID
  };
  lambdaApi.publishLayerVersion(params, (err, layer) => {
    if (err) {
      console.error(err);
      reject();
    } else {
      console.log("Layer uploaded. Adding to function...");
      const arn = layer.LayerVersionArn;
      addLayerToLambda(lambdaApi, functionConfig, arn, resolve, reject);
    }
  });
}

function setupLambdaLayer(lambdaApi, functionConfig) {
  // TODO: Determine required layer name using function runtime
  const requiredLayerName = _constants.RELAY_LAYER_ID;
  console.log("Searching for existing layer");
  const params = {
    CompatibleRuntime: functionConfig.Runtime
  };
  return new Promise((resolve, reject) => {
    lambdaApi.listLayers(params, (err, data) => {
      if (err) {
        console.error(err);
        reject();
      } else {
        const layerFound = data.Layers.some(layer => {
          if (layer.LayerName === requiredLayerName) {
            console.log("Existing layer found. Adding to function...");
            addLayerToLambda(lambdaApi, functionConfig, layer.LatestMatchingVersion.LayerVersionArn, resolve, reject);
            return true;
          }

          return false;
        });

        if (!layerFound) {
          console.log("No existing layer found");
          createAndAddLambdaLayer(lambdaApi, functionConfig, resolve, reject);
        }
      }
    });
  });
}

function removeLambdaLayer(lambdaApi, fullFunc) {
  let layers = fullFunc.Layers || [];
  layers = layers.filter(layer => !layer.Arn.includes(_constants.RELAY_ID));
  layers = layers.map(layer => layer.Arn);
  const params = {
    FunctionName: fullFunc.FunctionName,
    Runtime: "nodejs10.x",
    Layers: layers
  };
  return new Promise((resolve, reject) => {
    lambdaApi.updateFunctionConfiguration(params, err => {
      if (err) {
        console.error(err);
        reject();
      }

      console.log("Relay Layer Removed");
      resolve();
    });
  });
}

module.exports = {
  removeLambdaLayer,
  setupLambdaLayer
};
